@@ -3,9 +3,10 @@ from datetime import datetime
 import psycopg2
 import datetime
 from dpl_geodb.geo_ops import config
+import typing
 
 @dataclass
-class PictureReference -> int, str:
+class PictureReference:
     original_name: str
     temporary_name: str
     file_size: str
@@ -13,7 +14,7 @@ class PictureReference -> int, str:
     lat: str = ""
     lng: str = ""
 
-    def insert_reference(self):
+    def insert_reference(self) -> typing.Union[int, str]:
         connection = None
         db_parameters = config()
         connection = psycopg2.connect(**db_parameters)
