@@ -3,7 +3,8 @@ import typing
 from dpl_geodb.geo_ops import config
 
 
-def thumb_querie(id:int) -> tuple:
+def thumb_querie(id:int) -> typing.Union[tuple, str]:
+    # TODO operate off of uuids
     connection = None
         db_parameters = config()
         connection = psycopg2.connect(**db_parameters)
@@ -13,7 +14,7 @@ def thumb_querie(id:int) -> tuple:
             cursor.execute(select_command, id)
             pic_ref = cursor.fetchone()[0]
         except:
-            return tuple(("error"))
+            return "error"
         finally:
             if connection is not None:
                 connection.close()
